#!/bin/bash -xe

SRCDIR=${PWD}
TARGET=$1

usage()
{
    echo "Usage: $0 [cross|hisilicon|local]"
}

if [ -f "/lib64/libc.so.6" ]; then
    LIBC_SO_PATH=/lib64/libc.so.6
elif [ -f "/lib32/libc.so.6" ]; then
    LIBC_SO_PATH=/lib32/libc.so.6
elif [ -f "/lib/x86_64-linux-gnu/libc.so.6" ]; then
    LIBC_SO_PATH=/lib/x86_64-linux-gnu/libc.so.6
elif [ -f "/lib/libc.so.6" ]; then
    LIBC_SO_PATH=/lib/libc.so.6
else
    LIBC_SO_PATH=/lib/libc.so.6
fi

GLIBC_VERSION=`${LIBC_SO_PATH} | head -n 1 | sed -e 's/.*\(version [0-9]\.[0-9]*\).*/\1/' | sed -e 's/version //g'`
if [ "x${GLIBC_VERSION}" = "x" ]; then
    echo "failed to detect glibc version. check host os environment."
    exit 1
fi

# 2.5 for CentOS 5.x
# 2.12 for CentOS 6.x
# 2.15 for Ubuntu 12.04 LTS
echo "detected glibc version = ${GLIBC_VERSION}"

case "${TARGET}" in
    cross)
        DESTDIR=${SRCDIR}/../../export/arm-sony-linux-gnueabi-armv7a
        DESTLIBDIR=${SRCDIR}/../../export/arm-sony-linux-gnueabi-armv7a/lib
        which arm-sony-linux-gnueabi-armv7a-gcc
        CC=arm-sony-linux-gnueabi-armv7a-gcc
        ;;
    hisilicon)
        DESTDIR=${SRCDIR}/../../export/arm-hisiv600-linux-gnueabi
        DESTLIBDIR=${SRCDIR}/../../export/arm-hisiv600-linux-gnueabi/lib
        which arm-hisiv600-linux-gnueabi-gcc
        CC=arm-hisiv600-linux-gnueabi-gcc
        ;;
    local)
        if [ -x /usr/bin/gcc-6 ]; then
            export CC=/usr/bin/gcc-6
        else
            export CC=/usr/bin/gcc
        fi
        if [ -x /usr/bin/g++-6 ]; then
            export CXX=/usr/bin/g++-6
        else
            export CXX=/usr/bin/g++
        fi
        DESTDIR=${SRCDIR}/../../export/x86_64_pc_linux_gnu
        DESTLIBDIR=${SRCDIR}/../../export/x86_64_pc_linux_gnu/lib/${GLIBC_VERSION}
        ;;
    *)
        usage
        exit 0
        ;;
esac

make clean
make CC="$CC" rsbep librsbep.so

cp src/rs.h ${DESTDIR}/include/
cp -a rsbep ${DESTDIR}/bin/
cp -a librsbep.so ${DESTLIBDIR}/
